@@ -602,33 +602,39 @@ Kokkos::View<T*> from_std_vector(const std::vector<T> &v)
     void visit_Print(const ASR::Print_t &x) {
         std::string indent(indentation_level*indentation_spaces, ' ');
         std::string out = indent + "std::cout ", sep;
-        if (x.m_separator) {
-            this->visit_expr(*x.m_separator);
-            sep = src;
-        } else {
-            sep = "\" \"";
+        //HACKISH way to handle print refactoring (always using stringformat).
+        // TODO : Implement stringformat visitor.
+        ASR::StringFormat_t* str_fmt = nullptr;
+        size_t n_values = x.n_values;
+        sep = "\" \"";
+        if(x.m_values[0] && ASR::is_a<ASR::StringFormat_t>(*x.m_values[0])) {
+            str_fmt = ASR::down_cast<ASR::StringFormat_t>(x.m_values[0]);
+            n_values = str_fmt->n_args;
         }
-        for (size_t i=0; i<x.n_values; i++) {
-            this->visit_expr(*x.m_values[i]);
+        for (size_t i=0; i<n_values; i++) {
+            str_fmt? this->visit_expr(*(str_fmt->m_args[i])): this->visit_expr(*x.m_values[i]);
             out += "<< " + src + " ";
-            if (i+1 != x.n_values) {
+            if (i+1 != n_values) {
                 out += "<< " + sep + " ";
             }
         }
-        if (x.m_end) {
-            this->visit_expr(*x.m_end);
-            out += "<< " + src + ";\n";
-        } else {
-            out += "<< std::endl;\n";
-        }
+        out += "<< std::endl;\n";
         src = out;
     }
 
     void visit_FileWrite(const ASR::FileWrite_t &x) {
         std::string indent(indentation_level*indentation_spaces, ' ');
         std::string out = indent + "std::cout ";
-        for (size_t i=0; i<x.n_values; i++) {
-            this->visit_expr(*x.m_values[i]);
+        //HACKISH way to handle print refactoring (always using stringformat).
+        // TODO : Implement stringformat visitor.
+        ASR::StringFormat_t* str_fmt = nullptr;
+        size_t n_values = x.n_values;
+        if(x.m_values[0] && ASR::is_a<ASR::StringFormat_t>(*x.m_values[0])) {
+            str_fmt = ASR::down_cast<ASR::StringFormat_t>(x.m_values[0]);
+            n_values = str_fmt->n_args;
+        }
+        for (size_t i=0; i<n_values; i++) {
+            str_fmt? this->visit_expr(*(str_fmt->m_args[i])): this->visit_expr(*x.m_values[i]);
             out += "<< " + src + " ";
         }
         out += "<< std::endl;\n";
