@@ -47,14 +47,15 @@ class ReplaceArrayConstant: public ASR::BaseExprReplacer<ReplaceArrayConstant> {
         ASR::expr_t* d = implied_doloop->m_increment;
         ASR::expr_t* implied_doloop_size = nullptr;
         int kind = ASRUtils::extract_kind_from_ttype_t(ASRUtils::expr_type(end));
+        start = builder.i2i_t(start, ASRUtils::expr_type(end));
         if( d == nullptr ) {
-            implied_doloop_size = builder.ElementalAdd(
-                builder.ElementalSub(end, start, loc),
-                make_ConstantWithKind(make_IntegerConstant_t, make_Integer_t, 1, kind, loc), loc);
+            implied_doloop_size = builder.Add(
+                builder.Sub(end, start),
+                make_ConstantWithKind(make_IntegerConstant_t, make_Integer_t, 1, kind, loc));
         } else {
-            implied_doloop_size = builder.ElementalAdd(builder.ElementalDiv(
-                builder.ElementalSub(end, start, loc), d, loc),
-                make_ConstantWithKind(make_IntegerConstant_t, make_Integer_t, 1, kind, loc), loc);
+            implied_doloop_size = builder.Add(builder.Div(
+                builder.Sub(end, start), d),
+                make_ConstantWithKind(make_IntegerConstant_t, make_Integer_t, 1, kind, loc));
         }
         int const_elements = 0;
         ASR::expr_t* implied_doloop_size_ = nullptr;
@@ -64,9 +65,9 @@ class ReplaceArrayConstant: public ASR::BaseExprReplacer<ReplaceArrayConstant> {
                     implied_doloop_size_ = get_ImpliedDoLoop_size(
                         ASR::down_cast<ASR::ImpliedDoLoop_t>(implied_doloop->m_values[i]));
                 } else {
-                    implied_doloop_size_ = builder.ElementalAdd(get_ImpliedDoLoop_size(
+                    implied_doloop_size_ = builder.Add(get_ImpliedDoLoop_size(
                         ASR::down_cast<ASR::ImpliedDoLoop_t>(implied_doloop->m_values[i])),
-                        implied_doloop_size_, loc);
+                        implied_doloop_size_);
                 }
             } else {
                 const_elements += 1;
@@ -77,20 +78,20 @@ class ReplaceArrayConstant: public ASR::BaseExprReplacer<ReplaceArrayConstant> {
                 implied_doloop_size_ = make_ConstantWithKind(make_IntegerConstant_t,
                     make_Integer_t, const_elements, kind, loc);
             } else {
-                implied_doloop_size_ = builder.ElementalAdd(
+                implied_doloop_size_ = builder.Add(
                     make_ConstantWithKind(make_IntegerConstant_t,
                         make_Integer_t, const_elements, kind, loc),
-                    implied_doloop_size_, loc);
+                    implied_doloop_size_);
             }
         }
         if( implied_doloop_size_ ) {
-            implied_doloop_size = builder.ElementalMul(implied_doloop_size_, implied_doloop_size, loc);
+            implied_doloop_size = builder.Mul(implied_doloop_size_, implied_doloop_size);
         }
         return implied_doloop_size;
     }
 
     size_t get_constant_ArrayConstant_size(ASR::ArrayConstant_t* x) {
-        return x->n_args;
+        return ASRUtils::get_fixed_size_of_array(x->m_type);
     }
 
     ASR::expr_t* get_ArrayConstructor_size(ASR::ArrayConstructor_t* x, bool& is_allocatable) {
@@ -111,8 +112,8 @@ class ReplaceArrayConstant: public ASR::BaseExprReplacer<ReplaceArrayConstant> {
                     if( array_size == nullptr ) {
                         array_size = element_array_size;
                     } else {
-                        array_size = builder.ElementalAdd(array_size,
-                                        element_array_size, x->base.base.loc);
+                        array_size = builder.Add(array_size,
+                                        element_array_size);
                     }
                 }
             } else if( ASR::is_a<ASR::ArrayConstructor_t>(*element) ) {
@@ -121,8 +122,8 @@ class ReplaceArrayConstant: public ASR::BaseExprReplacer<ReplaceArrayConstant> {
                 if( array_size == nullptr ) {
                     array_size = element_array_size;
                 } else {
-                    array_size = builder.ElementalAdd(array_size,
-                                    element_array_size, x->base.base.loc);
+                    array_size = builder.Add(array_size,
+                                    element_array_size);
                 }
             } else if( ASR::is_a<ASR::Var_t>(*element) ) {
                 ASR::ttype_t* element_type = ASRUtils::type_get_past_allocatable(
@@ -137,8 +138,8 @@ class ReplaceArrayConstant: public ASR::BaseExprReplacer<ReplaceArrayConstant> {
                         if( array_size == nullptr ) {
                             array_size = element_array_size;
                         } else {
-                            array_size = builder.ElementalAdd(array_size,
-                                            element_array_size, x->base.base.loc);
+                            array_size = builder.Add(array_size,
+                                            element_array_size);
                         }
                     }
                 } else {
@@ -148,7 +149,7 @@ class ReplaceArrayConstant: public ASR::BaseExprReplacer<ReplaceArrayConstant> {
                 ASR::expr_t* implied_doloop_size = get_ImpliedDoLoop_size(
                     ASR::down_cast<ASR::ImpliedDoLoop_t>(element));
                 if( array_size ) {
-                    array_size = builder.ElementalAdd(implied_doloop_size, array_size, loc);
+                    array_size = builder.Add(implied_doloop_size, array_size);
                 } else {
                     array_size = implied_doloop_size;
                 }
@@ -162,19 +163,19 @@ class ReplaceArrayConstant: public ASR::BaseExprReplacer<ReplaceArrayConstant> {
                     if( d == nullptr ) {
                         continue;
                     }
-                    ASR::expr_t* dim_size = builder.ElementalAdd(builder.ElementalDiv(
-                        builder.ElementalSub(end, start, loc), d, loc),
-                        make_ConstantWithKind(make_IntegerConstant_t, make_Integer_t, 1, 4, loc), loc);
+                    ASR::expr_t* dim_size = builder.Add(builder.Div(
+                        builder.Sub(end, start), d),
+                        make_ConstantWithKind(make_IntegerConstant_t, make_Integer_t, 1, 4, loc));
                     if( array_section_size == nullptr ) {
                         array_section_size = dim_size;
                     } else {
-                        array_section_size = builder.ElementalMul(array_section_size, dim_size, loc);
+                        array_section_size = builder.Mul(array_section_size, dim_size);
                     }
                 }
                 if( array_size == nullptr ) {
                     array_size = array_section_size;
                 } else {
-                    builder.ElementalAdd(array_section_size, array_size, loc);
+                    builder.Add(array_section_size, array_size);
                 }
             } else {
                 constant_size += 1;
@@ -192,7 +193,7 @@ class ReplaceArrayConstant: public ASR::BaseExprReplacer<ReplaceArrayConstant> {
             }
         }
         if( constant_size_asr ) {
-            array_size = builder.ElementalAdd(array_size, constant_size_asr, x->base.base.loc);
+            array_size = builder.Add(array_size, constant_size_asr);
         }
         is_allocatable = true;
         if( array_size == nullptr ) {
@@ -411,6 +412,8 @@ class ArrayConstantVisitor : public ASR::CallReplacerOnExpressionsVisitor<ArrayC
 
         Allocator& al;
         bool remove_original_statement, allocate_target = false;
+        bool print = false, file_write = false;
+        ASR::expr_t* m_unit = nullptr;
         ReplaceArrayConstant replacer;
         Vec<ASR::stmt_t*> pass_result;
         Vec<ASR::stmt_t*>* parent_body;
@@ -425,6 +428,8 @@ class ArrayConstantVisitor : public ASR::CallReplacerOnExpressionsVisitor<ArrayC
         parent_body(nullptr) {
             pass_result.n = 0;
             pass_result.reserve(al, 0);
+            print = false, file_write = false;
+            m_unit = nullptr;
         }
 
         void visit_Variable(const ASR::Variable_t& /*x*/) {
@@ -525,7 +530,39 @@ class ArrayConstantVisitor : public ASR::CallReplacerOnExpressionsVisitor<ArrayC
             return array_constant;
         }
 
+        ASR::stmt_t* create_do_loop_form_idl(ASR::ImpliedDoLoop_t* x) {
+            ASR::stmt_t* do_loop = nullptr;
+
+            ASR::do_loop_head_t do_loop_head;
+            do_loop_head.loc = x->base.base.loc; do_loop_head.m_v = x->m_var;
+            do_loop_head.m_start = x->m_start; do_loop_head.m_end = x->m_end;
+            do_loop_head.m_increment = x->m_increment;
+
+            Vec<ASR::stmt_t*> do_loop_body; do_loop_body.reserve(al, x->n_values);
+            for (size_t i = 0; i < x->n_values; i++ ) {
+                if ( ASR::is_a<ASR::ImpliedDoLoop_t>(*x->m_values[i]) ) {
+                    do_loop_body.push_back(al, create_do_loop_form_idl(
+                        ASR::down_cast<ASR::ImpliedDoLoop_t>(x->m_values[i])));
+                } else {
+                    Vec<ASR::expr_t*> print_values; print_values.reserve(al, 1);
+                    print_values.push_back(al, x->m_values[i]);
+                    ASR::stmt_t* stmt = nullptr;
+                    if ( print ) {
+                        stmt = ASRUtils::STMT(ASR::make_Print_t(al, x->m_values[i]->base.loc, print_values.p, print_values.size(), nullptr, nullptr));
+                    } else {
+                        // this will be file_write
+                        LCOMPILERS_ASSERT(file_write);
+                        stmt = ASRUtils::STMT(ASR::make_FileWrite_t(al, x->m_values[i]->base.loc, 0, m_unit, nullptr, nullptr, nullptr, print_values.p, print_values.size(), nullptr, nullptr, nullptr));
+                    }
+                    do_loop_body.push_back(al, stmt);
+                }
+            }
+            do_loop = ASRUtils::STMT(ASR::make_DoLoop_t(al, x->base.base.loc, nullptr, do_loop_head, do_loop_body.p, do_loop_body.size(), nullptr, 0));
+            return do_loop;
+        }
+
         void visit_Print(const ASR::Print_t &x) {
+            print = true;
             /*
                 integer :: i
                 print *, (i, i=1, 10)
@@ -561,6 +598,7 @@ class ArrayConstantVisitor : public ASR::CallReplacerOnExpressionsVisitor<ArrayC
                     }
                 }
             }
+            print = false;
         }
 
         void visit_StringFormat(const ASR::StringFormat_t &x) {
@@ -577,6 +615,12 @@ class ArrayConstantVisitor : public ASR::CallReplacerOnExpressionsVisitor<ArrayC
             for(size_t i = 0; i < x.n_args; i++) {
                 ASR::expr_t* value = x.m_args[i];
                 if (ASR::is_a<ASR::ImpliedDoLoop_t>(*value)) {
+                    ASR::ImpliedDoLoop_t* implied_do_loop = ASR::down_cast<ASR::ImpliedDoLoop_t>(value);
+                    if ( ASR::is_a<ASR::Tuple_t>(*implied_do_loop->m_type) ) {
+                        remove_original_statement = true;
+                        pass_result.push_back(al, create_do_loop_form_idl(implied_do_loop));
+                        continue;
+                    }
                     ASR::asr_t* array_constant = create_array_constant(x, value);
                     string_format_stmt->m_args[i] = ASRUtils::EXPR(array_constant);
 
@@ -610,9 +654,12 @@ class ArrayConstantVisitor : public ASR::CallReplacerOnExpressionsVisitor<ArrayC
         }
 
         void visit_FileWrite(const ASR::FileWrite_t &x) {
+            file_write = true;
+            m_unit = x.m_unit;
             if (x.m_overloaded) {
                 this->visit_stmt(*x.m_overloaded);
                 remove_original_statement = false;
+                file_write = false;
                 return;
             }
 
@@ -652,6 +699,7 @@ class ArrayConstantVisitor : public ASR::CallReplacerOnExpressionsVisitor<ArrayC
                     }
                 }
             }
+            file_write = false;
         }
 
         void visit_CPtrToPointer(const ASR::CPtrToPointer_t& x) {
