@@ -106,7 +106,7 @@ private:
     // present in function symbol table.
     std::map<std::string, ASR::symbol_t*> arg2value;
 
-    std::string current_routine;
+    std::string& current_routine;
 
     bool inline_external_symbol_calls;
 
@@ -312,7 +312,9 @@ public:
             }
             if( !ASR::is_a<ASR::Variable_t>(*itr.second) ||
                  ASRUtils::is_character(*ASRUtils::symbol_type(itr.second)) ||
-                 ASRUtils::is_array(ASRUtils::symbol_type(itr.second)) ) {
+                 ASRUtils::is_array(ASRUtils::symbol_type(itr.second)) ||
+                 ASR::is_a<ASR::StructType_t>(*ASRUtils::symbol_type(itr.second)) ||
+                 ASR::is_a<ASR::ClassType_t>(*ASRUtils::symbol_type(itr.second)) ) {
                 arg2value.clear();
                 return ;
             }
@@ -333,10 +335,6 @@ public:
                     break;
                 }
                 ASR::ttype_t* local_var_type = func_var->m_type;
-                if( ASR::is_a<ASR::Const_t>(*local_var_type) ) {
-                    local_var_type = ASR::down_cast<ASR::Const_t>(local_var_type)->m_type;
-                }
-                LCOMPILERS_ASSERT(!ASR::is_a<ASR::Const_t>(*local_var_type));
                 ASR::symbol_t* local_var = (ASR::symbol_t*) ASR::make_Variable_t(
                         al, func_var->base.base.loc, current_scope,
                         s2c(al, local_var_name), nullptr, 0, ASR::intentType::Local,
